@@ -77,23 +77,23 @@ parse_xml (const gchar  *data,
 }
 
 gboolean
-davdoc_parse (DavDoc *dd, SoupMessage *msg, SoupMessageBody *body,
+davdoc_parse (DavDoc *dd, SoupServerMessage *msg, SoupMessageBody *body,
               const gchar *name)
 {
   xmlDocPtr doc;
   xmlNodePtr root;
-  SoupURI *uri;
+  GUri *uri;
 
   doc = parse_xml (body->data, body->length, &root, name);
   if (!doc)
     return FALSE;
 
-  uri = soup_message_get_uri (msg);
+  uri = soup_server_message_get_uri (msg);
 
   dd->doc = doc;
   dd->root = root;
   dd->target = uri;
-  dd->path = g_uri_unescape_string (uri->path, "/");
+  dd->path = g_uri_unescape_string (g_uri_get_path (uri), "/");
 
   return TRUE;
 }
